:html_theme.sidebar_secondary.remove:

##########
User guide
##########

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   set-up-from-template
   template-manual

.. toctree::
   :maxdepth: 1
   :caption: Guides

   logging
   http-client
   database/index
   arq
   gafaelfawr
   x-forwarded
   ivoa
   kafka/index
   kubernetes
   metrics/index
   pydantic
   pydantic-redis
   gcs
   fastapi-errors
   datetime
   uvicorn
   slack-webhook
   github-apps/index
   click
   asyncio-queue
   uws/index
   sentry
